@@ -32,6 +32,7 @@ def convertModelToRawData(model, columns, num_data, batch_input_shape=None, num_
     Given a model, convert model conf into dataframe
     The columns of dataframe depends on the global variable options
     """
+    columns = [x for x in columns if "out_dim" not in x] + [f"out_dim_{x}" for x in range(num_dim)]
     df = pd.DataFrame(columns=columns)
     try:
         model.summary(print_fn=lambda x: "")
@@ -83,7 +84,8 @@ def convertRawDataToModel(df):
         l_name = df.iloc[i].layer
         if l_name not in OPTIONS["Model"]["layer"]:
             # only add those layer was in our layer type choices
-            print(f"WARNING: {l_name} layer was skip as not listed in OPTIONS")
+            if l_name.lower() != "inputlayer":
+                print(f"WARNING: {l_name} layer was skip as not listed in OPTIONS")
             continue
         kwargs = df.iloc[i].drop(drop_cols).dropna().to_dict()
         model.add(getattr(keras.layers, l_name)(**kwargs))
